@@ -139,14 +139,14 @@ static void callerid_widget_dispose (GObject *gobject)
 	if (self->priv->bluez_telephony_proxy)
 		g_object_unref (self->priv->bluez_telephony_proxy);
 
-	if (self->priv->sys_dbus_conn)
-		dbus_g_connection_unref (self->priv->sys_dbus_conn);
+	/* if (self->priv->sys_dbus_conn)
+		dbus_g_connection_unref (self->priv->sys_dbus_conn); */
 
 	if (self->priv->ring_proxy)
 		g_object_unref (self->priv->ring_proxy);
 
-	if (self->priv->sess_dbus_conn)
-		dbus_g_connection_unref (self->priv->sess_dbus_conn);
+	/* if (self->priv->sess_dbus_conn)
+		dbus_g_connection_unref (self->priv->sess_dbus_conn); */
 
 	if (self->priv->ring_acc)
 		g_object_unref (self->priv->ring_acc);
@@ -327,7 +327,9 @@ static void callerid_widget_on_ready_update (McAccount *account, const GError *e
 	GHashTableIter iter;
 	gpointer key, value;
 
-	g_return_if_fail (error != NULL);
+	//g_return_if_fail (error == NULL);
+	if (error)
+		return;
 
 	parameters = mc_account_get_parameters (account);
 	g_return_if_fail (parameters != NULL);
@@ -355,7 +357,7 @@ static void callerid_widget_on_ready_read (McAccount *account, const GError *err
 	const gchar *result;
 	gchar *label;
 
-	g_return_if_fail (error != NULL);
+	g_return_if_fail (error == NULL);
 
 	parameters = mc_account_get_parameters (account);
 	g_return_if_fail (parameters != NULL);
@@ -375,18 +377,19 @@ static void callerid_widget_on_ready_read (McAccount *account, const GError *err
 	gtk_label_set_text (GTK_LABEL (self->priv->stateLabel), label);
 }
 
-/*static gboolean callerid_widget_leave_event (GtkWidget *widget G_GNUC_UNUSED, GdkEventCrossing *event G_GNUC_UNUSED, CallerIDWidget *self)*/
-/*{*/
-/*	self->priv->isPressed = FALSE;*/
-/*	gtk_widget_queue_draw (GTK_WIDGET (self));*/
-/*	*/
-/*	return FALSE;*/
-/*}*/
+static gboolean callerid_widget_leave_event (GtkWidget *widget G_GNUC_UNUSED, GdkEventCrossing *event G_GNUC_UNUSED, CallerIDWidget *self)
+{
+	self->priv->isPressed = FALSE;
+	gtk_widget_queue_draw (GTK_WIDGET (self));
+	
+	return FALSE;
+}
 
 static gboolean callerid_widget_button_release (GtkWidget *widget, GdkEventButton *event, CallerIDWidget *self)
 {
 	if (event->button == 1 && self->priv->isPressed)
 	{
+		//self->priv->isPressed = !self->priv->isPressed;
 		self->priv->isPressed = FALSE;
 
 		callerid_widget_new_callerid_combo (self);
@@ -400,7 +403,7 @@ static gboolean callerid_widget_button_release (GtkWidget *widget, GdkEventButto
 
 static gboolean callerid_widget_button_press (GtkWidget *widget, GdkEventButton *event, CallerIDWidget *self)
 {
-	if (event->button == 1)
+	if (event->button == 1) //&& !self->priv->isPressed)
 	{
 		self->priv->isPressed = TRUE;
 		gtk_widget_queue_draw (widget);
@@ -428,7 +431,7 @@ static void callerid_widget_content_create (CallerIDWidget *self)
 
 	g_signal_connect (self, "button-release-event", G_CALLBACK (callerid_widget_button_release), self);
 	g_signal_connect (self, "button-press-event", G_CALLBACK (callerid_widget_button_press), self);
-	//g_signal_connect (self, "leave-notify-event", G_CALLBACK (callerid_widget_leave_event), self);
+	g_signal_connect (self, "leave-notify-event", G_CALLBACK (callerid_widget_leave_event), self);
 
 	gtk_widget_show_all (self->priv->homeWidget);
 }
@@ -462,7 +465,9 @@ static void callerid_widget_init (CallerIDWidget *self)
 	self->priv = CALLERID_WIDGET_GET_PRIVATE (self);
 	g_return_if_fail (G_LIKELY (self->priv != NULL));
 
-	gtk_widget_add_events (GTK_WIDGET (self), GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK); //| GDK_LEAVE_NOTIFY_MASK);
+	self->priv->isPressed = FALSE;
+
+	gtk_widget_add_events (GTK_WIDGET (self), GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_LEAVE_NOTIFY_MASK);
 
 	self->priv->ring_acc = mc_account_new (daemon, TELEPATHY_RING_PATH);
 	g_object_unref (daemon);
